pub struct Summary {
pub metadata: Table,
pub target_packages: PackageMap,
pub host_packages: PackageMap,
}Expand description
An in-memory representation of a build summary.
For more, see the crate-level documentation.
Fields
metadata: TableExtra metadata associated with the summary.
This may be used for storing extra information about the summary.
Populate it from any Serialize type through Self::with_metadata.
target_packages: PackageMapThe packages and features built on the target platform.
host_packages: PackageMapThe packages and features built on the host platform.
Implementations
Sourceimpl Summary
impl Summary
Sourcepub fn with_metadata(metadata: &impl Serialize) -> Result<Self, Error>
pub fn with_metadata(metadata: &impl Serialize) -> Result<Self, Error>
Constructs a new summary with the provided metadata, and an empty target_packages and
host_packages.
Sourcepub fn diff<'a>(&'a self, other: &'a Summary) -> SummaryDiff<'a>
pub fn diff<'a>(&'a self, other: &'a Summary) -> SummaryDiff<'a>
Perform a diff of this summary against another.
This doesn’t diff the metadata, just the initials and packages.
Sourcepub fn write_to_string(&self, dst: &mut String) -> Result<(), Error>
pub fn write_to_string(&self, dst: &mut String) -> Result<(), Error>
Serializes this summary into the given TOML string, using pretty TOML syntax.
This serializes the summary using the toml_compat module, for
byte-identical output against previous versions of guppy-summaries which
used toml 0.5.